==> fotoalbum-0.104.tar.bz2: fotoalbum-0.104/src/base/utf_conv.cpp <==
/*
 * Copyright (C) 2011  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#include "utf_conv.h"

#include "xmldefs.h"
#include <cstdlib>
#include <iostream>
#include <iconv.h>
#include "../shared/lib_conversions.h"
#include "treepicdata.h"

namespace UTFConv
{      
   bool Valid(SimpleXMLTransfer* xData)
   {
     return(false);
   }
   
   int recode_iconv(std::string& in, iconv_t& ict)
   {
   #ifdef WIN32
     return(1);
   #else
     size_t insize  = in.length();
     size_t outsize = insize * 4;
     char*  outptr  = (char*)malloc(outsize);
     char*  inptr   = (char*)(in.c_str());
     char*  out     = outptr;
     
     // init
     iconv(ict, NULL, NULL, &outptr, &outsize);
     // conv
     int nRet = iconv(ict, &inptr, &insize, &outptr, &outsize);
     *outptr = '\0';
     
     in = out;
     free(out);
     
     if (nRet == -1)
       return(1);
     else
       return(0);
   #endif
   }
   
   int Convert(SimpleXMLTransfer* xData, iconv_t& ict)
   {
     int nErr = 0;
     std::string strBuf;
     for (int n=0; n<xData->getAttributeCount(); n++)
     {
       std::string strAN = xData->attributeName(n);
       if (strAN.compare(XMLNAME_TITLE)    == 0 ||
           strAN.compare(XMLNAME_COMMENT)  == 0 ||
           strAN.compare(XMLNAME_KEYWORDS) == 0)
       {
         strBuf = xData->attributeVal(n);
         if (!strBuf.empty())
         {
           nErr |= recode_iconv(strBuf, ict);
           xData->overwriteAttribute(n, strBuf);
         }
       }
       else if (strAN.compare(XMLNAME_PATH) == 0)
       {
         xData->overwriteAttribute(n, TreePicData::EncodePath(xData->attributeVal(n)));
       }
     }
     
     for (int n=0; n<xData->getChildCount(); n++)
       nErr |= Convert(xData->getChildAt(n), ict);
     
     return(nErr);
   }
   
   int Convert(SimpleXMLTransfer* xData, std::string strCharset)
   {
   #ifdef WIN32
     return(-1);
   #else
     int nRet;
     iconv_t ict = iconv_open("UTF-8", strCharset.c_str());
     if (ict == (iconv_t)-1)
     {
       std::cerr << "conversion not available\n";
       return(-1);
     }
     nRet = Convert(xData, ict);
     iconv_close(ict);
     return(nRet);
   #endif
   }
   
};

==> fotoalbum-0.201.tar.bz2: fotoalbum-0.201/src/base/utf_conv.cpp <==
/*
 * Copyright (C) 2011, 2012  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#include "utf_conv.h"

#include "xmldefs.h"
#include <cstdlib>
#include <iostream>
#include <iconv.h>
#include "../shared/lib_conversions.h"
#include "pic.h"

namespace UTFConv
{
   bool Valid(SimpleXMLTransfer* xData)
   {
     return(false);
   }
   
   int recode_iconv(std::string& in, iconv_t& ict)
   {
   #ifdef WIN32
     return(1);
   #else
     size_t insize  = in.length();
     size_t outsize = insize * 4;
     char*  outptr  = (char*)malloc(outsize);
     char*  inptr   = (char*)(in.c_str());
     char*  out     = outptr;
     
     // init
     iconv(ict, NULL, NULL, &outptr, &outsize);
     // conv
     int nRet = iconv(ict, &inptr, &insize, &outptr, &outsize);
     *outptr = '\0';
     
     in = out;
     free(out);
     
     if (nRet == -1)
       return(1);
     else
       return(0);
   #endif
   }
   
   int Convert(SimpleXMLTransfer* xData, iconv_t& ict)
   {
     int nErr = 0;
     std::string strBuf;
     for (int n=0; n<xData->getAttributeCount(); n++)
     {
       std::string strAN = xData->attributeName(n);
       if (strAN.compare(XMLNAME_TITLE)    == 0 ||
           strAN.compare(XMLNAME_COMMENT)  == 0 ||
           strAN.compare(XMLNAME_KEYWORDS) == 0)
       {
         strBuf = xData->attributeVal(n);
         if (!strBuf.empty())
         {
           nErr |= recode_iconv(strBuf, ict);
           xData->overwriteAttribute(n, strBuf);
         }
       }
       else if (strAN.compare(XMLNAME_PATH) == 0)
       {
         xData->overwriteAttribute(n, ItPic::EncodePath(xData->attributeVal(n)));
       }
     }
     
     for (int n=0; n<xData->getChildCount(); n++)
       nErr |= Convert(xData->getChildAt(n), ict);
     
     return(nErr);
   }
   
   int Convert(SimpleXMLTransfer* xData, std::string strCharset)
   {
   #ifdef WIN32
     return(-1);
   #else
     int nRet;
     iconv_t ict = iconv_open("UTF-8", strCharset.c_str());
     if (ict == (iconv_t)-1)
     {
       std::cerr << "conversion not available\n";
       return(-1);
     }
     nRet = Convert(xData, ict);
     iconv_close(ict);
     return(nRet);
   #endif
   }
   
};
